@@ -48,7 +48,8 @@ class DisableComputeServiceTask(base.MasakariTask):
     def execute(self, host_name):
         msg = "Disabling compute service on host: '%s'" % host_name
         self.update_details(msg)
-        self.novaclient.enable_disable_service(self.context, host_name)
+        self.novaclient.enable_disable_service(self.context, host_name,
+            reason=CONF.host_failure.service_disable_reason)
         # Sleep until nova-compute service is marked as disabled.
         log_msg = ("Sleeping %(wait)s sec before starting recovery "
                "thread until nova recognizes the node down.")
@@ -178,11 +179,10 @@ class EvacuateInstancesTask(base.MasakariTask):
                 periodic_call_stopped.wait)
         except etimeout.Timeout:
             with excutils.save_and_reraise_exception():
-                periodic_call_stopped.stop()
                 msg = ("Instance '%(uuid)s' is successfully evacuated but "
-                       "failed to stop.") % {'uuid': instance.id}
+                       "timeout to stop.") % {'uuid': instance.id}
                 LOG.warning(msg)
-        else:
+        finally:
             periodic_call_stopped.stop()
 
     def _evacuate_and_confirm(self, context, instance, host_name,
@@ -224,13 +224,12 @@ class EvacuateInstancesTask(base.MasakariTask):
                 etimeout.with_timeout(
                     CONF.wait_period_after_evacuation,
                     periodic_call.wait)
-            except exception.InstanceEvacuateFailed as e:
-                LOG.warning(str(e))
-                failed_evacuation_instances.append(instance.id)
             except etimeout.Timeout:
-                # Instance is not evacuated in the expected time_limit.
-                failed_evacuation_instances.append(instance.id)
-            else:
+                with excutils.save_and_reraise_exception():
+                    msg = ("Timeout for instance '%(uuid)s' evacuation."
+                           % {'uuid': instance.id})
+                    LOG.warning(msg)
+            finally:
                 # stop the periodic call, in case of exceptions or
                 # Timeout.
                 periodic_call.stop()
@@ -251,6 +250,12 @@ class EvacuateInstancesTask(base.MasakariTask):
                 if vm_state == 'resized' and power_state != SHUTDOWN:
                     stop_instance = False
 
+            elif vm_state == 'stopped' and task_state is None:
+                # If vm_state is stopped and task_state is none, the instance
+                # will be recovered with vm_state 'stopped'.
+                # So it doesn't need to stop the instance after evacuation.
+                stop_instance = False
+
             elif task_state is not None:
                 # Nova fails evacuation when the instance's task_state is not
                 # none. In this case, masakari resets the instance's vm_state
@@ -277,9 +282,10 @@ class EvacuateInstancesTask(base.MasakariTask):
         except etimeout.Timeout:
             # Instance is not stop in the expected time_limit.
             failed_evacuation_instances.append(instance.id)
-        except Exception:
+        except Exception as e:
             # Exception is raised while resetting instance state or
             # evacuating the instance itself.
+            LOG.warning(str(e))
             failed_evacuation_instances.append(instance.id)
         finally:
             if not instance_already_locked:
@@ -328,13 +334,6 @@ class EvacuateInstancesTask(base.MasakariTask):
                                 self.update_details(msg, 1.0)
                                 LOG.info(msg)
 
-                            # A failed compute host can be associated with
-                            # multiple aggregates but operators will not
-                            # associate it with multiple aggregates in real
-                            # deployment so adding reserved_host to the very
-                            # first aggregate from the list.
-                            break
-
                 self.novaclient.enable_disable_service(
                     context, reserved_host, enable=True)
 
