@@ -20,12 +20,15 @@ Unit Tests for process failure TaskFlow
 from unittest import mock
 
 from masakari.compute import nova
+from masakari import conf
 from masakari import context
 from masakari.engine.drivers.taskflow import process_failure
 from masakari import exception
 from masakari import test
 from masakari.tests.unit import fakes
 
+CONF = conf.CONF
+
 
 class ProcessFailureTestCase(test.TestCase):
 
@@ -39,6 +42,7 @@ class ProcessFailureTestCase(test.TestCase):
         # overriding 'wait_period_after_service_update' to 2 seconds
         # to reduce the wait period.
         self.override_config('wait_period_after_service_update', 2)
+        self.disabled_reason = CONF.process_failure.service_disable_reason
 
     @mock.patch('masakari.compute.nova.novaclient')
     @mock.patch('masakari.engine.drivers.taskflow.base.MasakariTask.'
@@ -63,9 +67,10 @@ class ProcessFailureTestCase(test.TestCase):
         task.execute(self.process_name, self.service_host)
 
         # verify service is disabled
-        self.assertTrue(self.novaclient.is_service_down(self.ctxt,
-                                                        self.service_host,
-                                                        self.process_name))
+        self.assertTrue(
+            self.novaclient.is_service_disabled(self.ctxt,
+                                                self.service_host,
+                                                self.process_name))
 
         # verify progress details
         _mock_notify.assert_has_calls([
@@ -120,7 +125,7 @@ class ProcessFailureTestCase(test.TestCase):
                                          binary="nova-compute",
                                          status="enabled")
 
-        def fake_is_service_down(context, host_name, binary):
+        def fake_is_service_disabled(context, host_name, binary):
             # assume that service is not disabled
             return False
 
@@ -129,8 +134,8 @@ class ProcessFailureTestCase(test.TestCase):
                                                       self.novaclient)
         task.execute(self.process_name, self.service_host)
 
-        with mock.patch.object(self.novaclient, 'is_service_down',
-                               fake_is_service_down):
+        with mock.patch.object(self.novaclient, 'is_service_disabled',
+                               fake_is_service_disabled):
             # test ConfirmComputeNodeDisabledTask
             task = process_failure.ConfirmComputeNodeDisabledTask(
                 self.ctxt, self.novaclient)
