@@ -16,7 +16,7 @@ import textwrap
 from unittest import mock
 
 import ddt
-import pep8
+import pycodestyle
 
 from masakari.hacking import checks
 from masakari import test
@@ -25,7 +25,9 @@ from masakari import test
 @ddt.ddt
 class HackingTestCase(test.NoDBTestCase):
     """This class tests the hacking checks in masakari.hacking.checks by
-    passing strings to the check methods like the pep8/flake8 parser would.
+    passing strings to the check methods like the pycodestyle/flake8 parser
+    would.
+
     The parser loops over each line in the file and then passes the
     parameters to the check method. The parameter names in the check method
     dictate what type of object is passed to the check method.
@@ -47,7 +49,7 @@ class HackingTestCase(test.NoDBTestCase):
         indent_level: indentation (with tabs expanded to multiples of 8)
         previous_indent_level: indentation on previous line
         previous_logical: previous logical line
-        filename: Path of the file being run through pep8
+        filename: Path of the file being run through pycodestyle
 
     When running a test on a check method the return will be False/None if
     there is no violation in the sample input. If there is an error a tuple is
@@ -213,16 +215,16 @@ class HackingTestCase(test.NoDBTestCase):
             "msg = _('My message')",
             "masakari/tests/other_files3.py"))), 0)
 
-    # We are patching pep8 so that only the check under test is actually
+    # We are patching pycodestyle so that only the check under test is actually
     # installed.
-    @mock.patch('pep8._checks',
+    @mock.patch('pycodestyle._checks',
                 {'physical_line': {}, 'logical_line': {}, 'tree': {}})
     def _run_check(self, code, checker, filename=None):
-        pep8.register_check(checker)
+        pycodestyle.register_check(checker)
 
         lines = textwrap.dedent(code).lstrip().splitlines(True)
 
-        checker = pep8.Checker(filename=filename, lines=lines)
+        checker = pycodestyle.Checker(filename=filename, lines=lines)
         checker.check_all()
         checker.report._deferred_print.sort()
         return checker.report._deferred_print
